# semantic-navigator

[![Build Status](https://github.com/CouncilDataProject/semantic-navigator/workflows/CI/badge.svg)](https://github.com/CouncilDataProject/semantic-navigator/actions)
[![Documentation](https://github.com/CouncilDataProject/semantic-navigator/workflows/Documentation/badge.svg)](https://CouncilDataProject.github.io/semantic-navigator)

An active learning approach to query and search through large archival datasets.

---

## Installation

**Stable Release:** `pip install semantic-navigator`<br>
**Development Head:** `pip install git+https://github.com/CouncilDataProject/semantic-navigator.git`

## Documentation

For full package documentation please visit [CouncilDataProject.github.io/semantic-navigator](https://CouncilDataProject.github.io/semantic-navigator).

## Development

See [CONTRIBUTING.md](CONTRIBUTING.md) for information related to developing the code.

**MPLv2 License**
